=====
ZLMDB
=====

.. image:: https://img.shields.io/travis/crossbario/zlmdb.svg
    :target: https://travis-ci.org/crossbario/zlmdb
    :alt: TravisCI

.. image:: https://codecov.io/gh/crossbario/zlmdb/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/crossbario/zlmdb
    :alt: Coverage

.. image:: https://readthedocs.org/projects/zlmdb/badge/?version=latest
    :target: https://zlmdb.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation

.. image:: https://img.shields.io/pypi/v/zlmdb.svg
    :target: https://pypi.python.org/pypi/zlmdb
    :alt: PyPI

Object-relational zero-copy in-memory database layer for LMDB.


* Free software: MIT license
* Documentation: https://zlmdb.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
